| Title: | Dataset for Statistical Analysis |
|---|---|
| Description: | Data are essential in statistical analysis. This data package consists of four datasets for descriptive statistics, two datasets for statistical hypothesis testing, and two datasets for regression analysis. All of the datasets are based on Rattanalertnusorn, A. (2024) <https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>. |
| Authors: | Atchanut Rattanalertnusorn [aut, cre] |
| Maintainer: | Atchanut Rattanalertnusorn <[email protected]> |
| License: | CC0 |
| Version: | 0.1.0 |
| Built: | 2026-05-27 08:47:48 UTC |
| Source: | https://github.com/cran/datastat |
A dataset of the final scores of 10 students
data51data51
data51 is a data frame with 10 rows and 1 column:
Final score of each student
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.122-123.
data51data51
A dataset of midterm scores from 5 students. Each student took the exam two subjects: Thai and English
data52data52
data52 is a data frame with 5 rows and 2 columns:
Midterm score of English subject
Midterm score of Thai subject
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.125-128.
data52data52
A dataset of the weights of 10 persons measure in kilogram
data53data53
data53 is a data frame with 10 rows and 1 column:
Weight of each person
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.129-130.
data53data53
A dataset of five students. Each student has name, age and gender
data54data54
data54 is a data frame with 5 rows and 3 columns:
Student name
Student age
Student gender
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.147.
data54data54
A dataset of the weight of two car types (type A and type B). The weight measured in kilograms
data81data81
data81 is a data frame with 10 rows and 2 columns:
Weight of car type A
Weight of car type B
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.237.
data81data81
A dataset of the pre-test and post-test scores
data82data82
data82 is a data frame with 15 rows and 2 columns:
The pre-test score
The post-test score
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.247.
data82data82
A dataset of the advertising costs and sales
data91data91
data91 is a data frame with 9 rows and 2 columns:
The advertising costs are measured in a hundred thousand baht
The sales are measured in a million bath
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.265-266.
data91data91
A dataset of salary, overtime, and savings per month of 12 employees
data92data92
data91 is a data frame with 12 rows and 3 columns:
The salary of employees is measured in baht
The overtime of employees is measured in baht
The savings per month of employees are measured in baht
<https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>
Rattanalertnusorn, A. (2024). R and Its Application. TPN Press Ltd., Part. ISBN: 978-616-603-060-0. pp.275.
data92data92